@@ -2,6 +2,10 @@ from .als import als
 from .als import als2
 
 
+from .als_spectral import als_cheb
+from .als_spectral import als_spectral
+
+
 from .act_many import add_many
 from .act_many import outer_many
 
@@ -30,6 +34,7 @@ from .anova import anova
 
 
 from .cheb import cheb_bld
+from .cheb import cheb_diff_matrix
 from .cheb import cheb_get
 from .cheb import cheb_gets
 from .cheb import cheb_int
@@ -69,6 +74,7 @@ from .grid import grid_prep_opts
 from .grid import ind_qtt_to_tt
 from .grid import ind_to_poi
 from .grid import ind_tt_to_qtt
+from .grid import poi_scale
 from .grid import poi_to_ind
 from .grid import sample_lhs
 from .grid import sample_tt
@@ -92,6 +98,7 @@ from .props import size
 
 from .stat import cdf_confidence
 from .stat import cdf_getter
+from .stat import sample_ind_rand
 
 
 from .svd import matrix_skeleton
